<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="si">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>සත්‍යාපනය සාර්ථකයි</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>සත්‍යාපනය සාර්ථකයි</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>සත්‍යාපනය සාර්ථකයි</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthPasskey</name>
    <message>
        <source>Please plug in the security key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Identifying the security key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>සත්‍යාපනය සාර්ථකයි</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>වැරදි මුරපදයකි</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>මුර පදය</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>සත්‍යාපනය සාර්ථකයි</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>UKey is required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>පරිශීලක ගිණුම</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>මුරපදය කල් ඉකුත් වී ඇත, කරුණාකර වෙනස් කරන්න</translation>
    </message>
    <message>
        <source>Your password has expired. Please contact the administrator to change it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Terminal locked, please contact administrator</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DeepinAuthFramework</name>
    <message>
        <source>Wrong Password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>වැරදි මුරපදයකි</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>අවලංගු කරන්න</translation>
    </message>
    <message>
        <source>The reason of inhibit.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LighterGreeter</name>
    <message>
        <source>Standard Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>තිරය අගුළුලන්න</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>තිරය අගුළු ලෑම අසාර්ථකයි</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>ඇඟිලි සලකුණු සත්‍යාපනය කල් ඉකුත් වී ඇත, කරුණාකර ඔබගේ මුරපදය ඇතුලත් කරන්න</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>ඇඟිලි සලකුණු ගැලපීම අසාර්ථකයි</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>අවලංගු කරන්න</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>ඉහත පරිශීලකයින් තවමත් පුරනය වී සිටින අතර පද්ධතිය වසා දැමීම හේතුවෙන් දත්ත අස්ථානගතවිය හැකිය, මෙය සිදුකිරීම අවශ්‍ය යැයි ඔබට විශ්වාසද?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>ඉහත පරිශීලකයින් තවමත් පුරනය වී සිටින අතර පද්ධතිය නැවත ආරම්භ කිරීම හේතුවෙන් දත්ත අස්ථානගතවිය හැකිය, මෙය සිදුකිරීම අවශ්‍ය යැයි ඔබට විශ්වාසද?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>වසා දමන්න </translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>පද්ධතිය නැවත අරඹන්න</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>තාවකාලිකව වසාදමන්න </translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>ශිශිරකරණය කරන්න</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>අගුළු දමන්න</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>ඉවත් වන්න</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>පරීශීලක වෙනස් කිරීම</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>පද්ධතිය වෙනස් කිරීම</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>පද්ධති පිරික්සුම අරඹන්න</translation>
    </message>
</context>
<context>
    <name>UdcpMFALoginWidget</name>
    <message>
        <source>发送验证码</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>请输入手机号</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>请输入验证码</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>获取验证码</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please plug in and then install updates.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UsersWithTheSameName</name>
    <message>
        <source>Return</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please select the account for login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Local Account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Domain Account</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>දැනට ක්‍රියාත්මක වැඩසටහන් මඟින් පරිගණකය වසා දැමීම වළක්වයි. බලහත්කාරයෙන් පද්ධතිය වසා දැමීම, දත්ත අස්ථානගත වීමට හේතු විය හැක.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>වැඩසටහන වසා දැමීමට, අවලංගු කර, පසුව වැඩසටහන වසා දමන්න.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>දැනට ක්‍රියාත්මක වැඩසටහන් මඟින් පරිගණකය නැවත පණගැන්වීම වළක්වයි. බලහත්කාරයෙන් පද්ධතිය පණ ගැන්වීම දත්ත අස්ථානගත වීමට හේතු විය හැකිය.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>දැනට ක්‍රියාත්මක වැඩසටහන් මඟින් පරිගණකය අත්හිටුවීම වළක්වයි. බලහත්කාරයෙන් පද්ධතිය අත්හිටුවීම දත්ත අස්ථානගත වීමට හේතු විය හැකිය.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>දැනට ක්‍රියාත්මක වැඩසටහන් මඟින් පරිගණකය ශිශිරතරණය කිරීම වළක්වයි. බලහත්කාරයෙන් පද්ධතිය ශිශිරතරණය කිරීම දත්ත අස්ථානගත වීමට හේතු විය හැකිය.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>දැනට ක්‍රියාත්මක වැඩසටහන් මඟින් පරිගණකය පරිශීලක ගිණුමෙන් ඉවත් වීම වළක්වයි. බලහත්කාරයෙන් පරිශීලක ගිණුමෙන් ඉවත් වීම දත්ත අස්ථානගත වීමට හේතු විය හැකිය.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>වසා දමන්න </translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>පද්ධතිය නැවත අරඹන්න</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>තාවකාලිකව වසාදමන්න </translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>ශිශිරකරණය කරන්න</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>ඉවත් වන්න</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>පද්ධතිය වසා දැමීමට අවශ්‍ය බව ඔබට විශ්වාසද?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>පද්ධතිය නැවත ආරම්භ කිරීමට අවශ්‍ය බව ඔබට විශ්වාසද?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>පරිශීලක ගිණුමෙන් ඉවත් වීමට අවශ්‍ය බව ඔබට විශ්වාසද?</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and shutting down, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and rebooting, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and logging out, please wait...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::AssistLoginWidget</name>
    <message>
        <source>Automatic login</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>ක්‍රියාත්මක කරන්න</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>වසා දමන්න</translation>
    </message>
</context>
</TS>